@@ -3,6 +3,8 @@ package App::skryf::Util;
 use strict;
 use warnings;
 
+our $VERSION = '0.016_01'; # VERSION
+
 use Method::Signatures;
 use Text::MultiMarkdown 'markdown';
 use String::Dirify 'dirify';
@@ -12,7 +14,7 @@ use Encode;
 use DateTime::Format::RFC3339;
 
 method convert ($content, $use_wikilinks=0) {
-    markdown(trim($content), {
+    markdown($content, {
     empty_element_suffix => '>',
     tab_width => 2,
     use_wikilinks => $use_wikilinks,
@@ -41,7 +43,7 @@ method feed ($config, $posts) {
             title   => $post->{topic},
             link    => $config->{site} . '/post/' . $post->{slug},
             id      => $config->{site} . '/post/' . $post->{slug},
-            content => decode_utf8($post->{html}),
+            content => $post->{html},
             updated => $f->format_datetime($dt),
         );
     }
